@@ -16,6 +16,11 @@
 
 //  See http://www.boost.org for updates, documentation, and revision history.
 
+#include <boost/config.hpp>
+#ifdef BOOST_NO_STD_WSTREAMBUF
+#error "wide char i/o not supported on this platform"
+#else
+
 #include <boost/archive/text_wiarchive.hpp>
 #include <boost/archive/detail/polymorphic_iarchive_impl.hpp>
 
@@ -35,5 +40,6 @@ BOOST_BROKEN_COMPILER_TYPE_TRAITS_SPECIALIZATION(
     boost::archive::polymorphic_text_wiarchive
 )
 
+#endif // BOOST_NO_STD_WSTREAMBUF
 #endif // BOOST_ARCHIVE_POLYMORPHIC_TEXT_WIARCHIVE_HPP
 
