@@ -18,8 +18,7 @@
 #include <boost/test/unit_test.hpp>
 
 
-template<typename T>
-void    sinhc_pi_test(const char * more_blurb)
+BOOST_TEST_CASE_TEMPLATE_FUNCTION(sinhc_pi_test, T)
 {
     using    ::std::abs;
         
@@ -29,18 +28,15 @@ void    sinhc_pi_test(const char * more_blurb)
     
     
     BOOST_MESSAGE("Testing sinhc_pi in the real domain for "
-        << more_blurb << ".");
+        << string_type_name<T>::_() << ".");
     
-    BOOST_CHECK_PREDICATE(::std::less_equal<T>(), 2,
-        (
-            abs(sinhc_pi<T>(static_cast<T>(0))-static_cast<T>(1)),
-            numeric_limits<T>::epsilon()
-        ));
+    BOOST_CHECK_PREDICATE(::std::less_equal<T>(),
+        (abs(sinhc_pi<T>(static_cast<T>(0))-static_cast<T>(1)))
+        (numeric_limits<T>::epsilon()));
 }
 
 
-template<typename T>
-void    sinhc_pi_complex_test(const char * more_blurb)
+BOOST_TEST_CASE_TEMPLATE_FUNCTION(sinhc_pi_complex_test, T)
 {
     using    ::std::abs;
     using    ::std::sin;
@@ -51,14 +47,12 @@ void    sinhc_pi_complex_test(const char * more_blurb)
     
     
     BOOST_MESSAGE("Testing sinhc_pi in the complex domain for "
-        << more_blurb << ".");
+        << string_type_name<T>::_() << ".");
     
-    BOOST_CHECK_PREDICATE(::std::less_equal<T>(), 2,
-        (
-            abs(sinhc_pi<T>(::std::complex<T>(0, 1))-
-                ::std::complex<T>(sin(static_cast<T>(1)))),
-            numeric_limits<T>::epsilon()
-        ));
+    BOOST_CHECK_PREDICATE(::std::less_equal<T>(),
+        (abs(sinhc_pi<T>(::std::complex<T>(0, 1))-
+             ::std::complex<T>(sin(static_cast<T>(1)))))
+        (numeric_limits<T>::epsilon()));
 }
 
 
@@ -67,6 +61,7 @@ void    sinhc_pi_manual_check()
     using    ::boost::math::sinhc_pi;
     
     
+    BOOST_MESSAGE(" ");
     BOOST_MESSAGE("sinc_pi");
     
     for    (int i = 0; i <= 100; i++)
