@@ -30,75 +30,75 @@ test_main(int,char*[])
   {
     // typical range creation and extraction
     range r1(-3,5);
-    BOOST_TEST(r1.start() == -3);
-    BOOST_TEST(r1.finish() == 5);
-    BOOST_TEST(r1.stride() == 1);
-    BOOST_TEST(!r1.is_degenerate());
-    BOOST_TEST(r1.get_start(0) == -3);
-    BOOST_TEST(r1.get_finish(100) == 5);
+    BOOST_CHECK(r1.start() == -3);
+    BOOST_CHECK(r1.finish() == 5);
+    BOOST_CHECK(r1.stride() == 1);
+    BOOST_CHECK(!r1.is_degenerate());
+    BOOST_CHECK(r1.get_start(0) == -3);
+    BOOST_CHECK(r1.get_finish(100) == 5);
   }
 
   {
     range r2(-3,5,2);
-    BOOST_TEST(r2.start() == -3);
-    BOOST_TEST(r2.finish() == 5);
-    BOOST_TEST(r2.stride() == 2);
-    BOOST_TEST(!r2.is_degenerate());
+    BOOST_CHECK(r2.start() == -3);
+    BOOST_CHECK(r2.finish() == 5);
+    BOOST_CHECK(r2.stride() == 2);
+    BOOST_CHECK(!r2.is_degenerate());
   }
 
   {
     // degenerate creation
     range r3(5);
-    BOOST_TEST(r3.start() == 5);
-    BOOST_TEST(r3.finish() == 5);
-    BOOST_TEST(r3.stride() == 1);
-    BOOST_TEST(r3.is_degenerate());
+    BOOST_CHECK(r3.start() == 5);
+    BOOST_CHECK(r3.finish() == 5);
+    BOOST_CHECK(r3.stride() == 1);
+    BOOST_CHECK(r3.is_degenerate());
   }
 
   {
     // default range creation
     range r4;
-    BOOST_TEST(r4.get_start(0) == 0);
-    BOOST_TEST(r4.get_finish(100) == 100);
-    BOOST_TEST(r4.stride() == 1);
+    BOOST_CHECK(r4.get_start(0) == 0);
+    BOOST_CHECK(r4.get_finish(100) == 100);
+    BOOST_CHECK(r4.stride() == 1);
   }
 
   {
     // create a range using the setter methods
     range r5 = range().stride(2).start(-3).finish(7);
-    BOOST_TEST(r5.start() == -3);
-    BOOST_TEST(r5.stride() == 2);
-    BOOST_TEST(r5.finish() == 7);
+    BOOST_CHECK(r5.start() == -3);
+    BOOST_CHECK(r5.stride() == 2);
+    BOOST_CHECK(r5.finish() == 7);
   }
 
   // try out all the comparison operators
   {
     range r6 = -3 <= range().stride(2) < 7;
-    BOOST_TEST(r6.start() == -3);
-    BOOST_TEST(r6.stride() == 2);
-    BOOST_TEST(r6.finish() == 7);
+    BOOST_CHECK(r6.start() == -3);
+    BOOST_CHECK(r6.stride() == 2);
+    BOOST_CHECK(r6.finish() == 7);
   }
 
   {
     range r7 = -3 < range() <= 7;
-    BOOST_TEST(r7.start() == -2);
-    BOOST_TEST(r7.stride() == 1);
-    BOOST_TEST(r7.finish() == 8);
+    BOOST_CHECK(r7.start() == -2);
+    BOOST_CHECK(r7.stride() == 1);
+    BOOST_CHECK(r7.finish() == 8);
   }
 
   // arithmetic operators
   {
     range r8 = range(0,5) + 2;
-    BOOST_TEST(r8.start() == 2);
-    BOOST_TEST(r8.stride() == 1);
-    BOOST_TEST(r8.finish() == 7);
+    BOOST_CHECK(r8.start() == 2);
+    BOOST_CHECK(r8.stride() == 1);
+    BOOST_CHECK(r8.finish() == 7);
   }
 
   {
     range r9 = range(0,5) - 2;
-    BOOST_TEST(r9.start() == -2);
-    BOOST_TEST(r9.stride() == 1);
-    BOOST_TEST(r9.finish() == 3);
+    BOOST_CHECK(r9.start() == -2);
+    BOOST_CHECK(r9.stride() == 1);
+    BOOST_CHECK(r9.finish() == 3);
   }
 
   return boost::exit_success;
