@@ -8,6 +8,7 @@ namespace inherit3 {
     
 struct A
 {
+    A() { x = 0; }
     struct X { int y; };
     int x;
     virtual int foo() { return 0; }
@@ -24,6 +25,7 @@ struct A
 
 struct B: A
 {
+    B() { x = 0; }
     struct X { int y; };
     int x;
     int foo() { return 1; }
