@@ -1,8 +1,7 @@
-// Copyright David Abrahams 2002. Permission to copy, use,
-// modify, sell and distribute this software is granted provided this
-// copyright notice appears in all copies. This software is provided
-// "as is" without express or implied warranty, and with no claim as
-// to its suitability for any purpose.
+// Copyright David Abrahams 2002.
+// Distributed under the Boost Software License, Version 1.0. (See
+// accompanying file LICENSE_1_0.txt or copy at
+// http://www.boost.org/LICENSE_1_0.txt)
 
 #include <boost/python/handle.hpp>
 #include <boost/python/type_id.hpp>
@@ -75,8 +74,15 @@ namespace
 
           // Get the location in which to construct
           void* storage = ((rvalue_from_python_storage<T>*)data)->storage.bytes;
-          new (storage) T(SlotPolicy::extract(intermediate.get()));
-
+# ifdef _MSC_VER
+#  pragma warning(push)
+#  pragma warning(disable:4244)
+# endif 
+          new (storage) T( SlotPolicy::extract(intermediate.get()) );
+          
+# ifdef _MSC_VER
+#  pragma warning(pop)
+# endif 
           // record successful construction
           data->convertible = storage;
       }
