@@ -12,6 +12,8 @@
 #include <fstream>
 
 #include "test_tools.hpp"
+#include <boost/preprocessor/stringize.hpp>
+#include BOOST_PP_STRINGIZE(BOOST_ARCHIVE_TEST)
 #include <boost/serialization/level.hpp>
 #include <boost/serialization/nvp.hpp>
 
@@ -41,7 +43,7 @@ test_main( int /* argc */, char* /* argv */[] )
     A a;
     out(a);
     in(a);
-    return boost::exit_success;
+    return EXIT_SUCCESS;
 }
 
 // EOF
