@@ -14,6 +14,7 @@
 
 #include <cstdio> // remove
 #include <boost/config.hpp>
+
 #if defined(BOOST_NO_STDC_NAMESPACE)
 namespace std{ 
     using ::remove;
@@ -21,6 +22,8 @@ namespace std{
 #endif
 
 #include "test_tools.hpp"
+#include <boost/preprocessor/stringize.hpp>
+#include BOOST_PP_STRINGIZE(BOOST_ARCHIVE_TEST)
 
 #include <boost/serialization/nvp.hpp>
 #include "A.hpp"
@@ -43,5 +46,5 @@ test_main( int /* argc */, char* /* argv */[] )
         ia >> boost::serialization::make_nvp("a", a1);
     }
     std::remove(testfile);
-    return (a == a1) ? boost::exit_success : boost::exit_failure;
+    return (a == a1) ? EXIT_SUCCESS : EXIT_SUCCESS;
 }
