@@ -1,5 +1,5 @@
 
-# Copyright (c) MetaCommunications, Inc. 2003-2004
+# Copyright (c) MetaCommunications, Inc. 2003-2005
 #
 # Distributed under the Boost Software License, Version 1.0. 
 # (See accompanying file LICENSE_1_0.txt or copy at 
@@ -15,22 +15,22 @@ import shutil
 import stat
 import os.path
 import os
+import platform
 import traceback
 import string
 import sys
 
-regression_root = os.path.abspath( os.path.dirname( sys.argv[0] ) )
+regression_root    = os.path.abspath( os.path.dirname( sys.argv[0] ) )
 regression_results = os.path.join( regression_root, 'results' )
-regression_log = os.path.join( regression_results, 'bjam.log' )
-install_log = os.path.join( regression_results, 'bjam_install.log' )
+regression_log     = os.path.join( regression_results, 'bjam.log' )
+install_log        = os.path.join( regression_results, 'bjam_install.log' )
 
-boost_root = os.path.join( regression_root, 'boost' )
+boost_root      = os.path.join( regression_root, 'boost' )
 xsl_reports_dir = os.path.join( boost_root, 'tools', 'regression', 'xsl_reports' )
-comment_path = os.path.join( regression_root, 'comment.html' )
-timestamp_path = os.path.join( regression_root, 'timestamp' )
+timestamp_path  = os.path.join( regression_root, 'timestamp' )
 
-cvs_command_line = 'cvs -z9 %(command)s'
-cvs_ext_command_line = 'cvs -d:ext:%(user)s@cvs.sourceforge.net:/cvsroot/boost -z9 %(command)s'
+cvs_command_line         = 'cvs -z9 %(command)s'
+cvs_ext_command_line     = 'cvs -d:ext:%(user)s@cvs.sourceforge.net:/cvsroot/boost -z9 %(command)s'
 cvs_pserver_command_line = 'cvs -d:pserver:%(user)s@cvs.sourceforge.net:/cvsroot/boost -z9 %(command)s'
 
 bjam = {}
@@ -39,12 +39,21 @@ process_jam_log = {}
 if sys.platform == 'win32':
     bjam[ 'name' ] = 'bjam.exe'
     bjam[ 'build_cmd' ] = lambda toolset: 'build.bat %s' % toolset
+    bjam[ 'is_supported_toolset' ] = lambda x: x in [ 'borland', 'como', 'gcc', 'gcc-nocygwin' \
+                                                    , 'intel-win32', 'metrowerks', 'mingw' \
+                                                    , 'msvc', 'vc7' \
+                                                    ]
     process_jam_log[ 'name' ] = 'process_jam_log.exe'
     process_jam_log[ 'default_toolset' ] = 'vc-7_1'
     patch_boost_name = 'patch_boost.bat'
 else:
     bjam[ 'name' ] = 'bjam'
     bjam[ 'build_cmd' ] = lambda toolset:'./build.sh %s' % toolset
+    bjam[ 'is_supported_toolset' ] = lambda x: x in [ 'acc', 'como', 'darwin', 'gcc' \
+                                                    , 'intel-linux', 'kcc', 'kylix' \
+                                                    , 'mipspro', 'sunpro', 'tru64cxx' \
+                                                    , 'vacpp'\
+                                                    ]
     process_jam_log[ 'name' ] = 'process_jam_log'
     process_jam_log[ 'default_toolset' ] = 'gcc'
     patch_boost_name = './patch_boost'
@@ -61,7 +70,8 @@ process_jam_log[ 'build_path_root' ] = os.path.join(
     , process_jam_log[ 'name' ]
     )
 
-process_jam_log[ 'build_cmd' ] = lambda toolset:'%s -sTOOLS=%s'% ( tool_path( bjam ), toolset )
+process_jam_log[ 'build_cmd' ] = lambda toolset: bjam_command( toolset )
+process_jam_log[ 'is_supported_toolset' ] = lambda x : True
 
 build_monitor_url = 'http://www.meta-comm.com/engineering/resources/build_monitor.zip'
 pskill_url = 'http://www.sysinternals.com/files/pskill.zip'
@@ -74,6 +84,14 @@ def log( message ):
     sys.stderr.flush()
 
 
+def platform_name():
+    # See http://article.gmane.org/gmane.comp.lib.boost.testing/933
+    if sys.platform == 'win32':
+        return 'Windows'
+
+    return platform.system()
+
+
 def rmtree( path ):
     if os.path.exists( path ):
         if sys.platform == 'win32':
@@ -83,7 +101,7 @@ def rmtree( path ):
             os.system( 'rm -f -r "%s"' % path )
 
 
-def retry( f, args, max_attempts=2, sleep_secs=10 ):
+def retry( f, args, max_attempts=5, sleep_secs=10 ):
     for attempts in range( max_attempts, -1, -1 ):
         try:
             return f( *args )
@@ -105,6 +123,10 @@ def cleanup( args, **unused ):
         rmtree( boost_root )
     
     if 'bin' in args:
+        boost_bin_dir = os.path.join( boost_root, 'bin' )
+        log( 'Cleaning up "%s" directory ...' % boost_bin_dir )
+        rmtree( boost_bin_dir )
+
         log( 'Cleaning up "%s" directory ...' % regression_results )
         rmtree( regression_results )
 
@@ -125,8 +147,13 @@ def http_get( source_url, destination, proxy ):
     src.close()
 
 
-def download_boost_tarball( destination, tag, proxy ):
-    tarball_name = 'boost-%s.tar.bz2' % tag
+def tarball_name_for_tag( tag, timestamp = False ):
+    if not timestamp: return 'boost-%s.tar.bz2' % tag
+    else:             return 'boost-%s.timestamp' % tag
+
+
+def download_boost_tarball( destination, tag, proxy, timestamp_only = False ):
+    tarball_name = tarball_name_for_tag( tag, timestamp_only )
     tarball_path = os.path.join( destination, tarball_name )
     tarball_url = 'http://www.meta-comm.com/engineering/boost/snapshot/%s' % tarball_name
 
@@ -139,7 +166,7 @@ def download_boost_tarball( destination, tag, proxy ):
         , tarball_path
         , proxy
         )
-        
+
     return tarball_path
 
 
@@ -159,13 +186,12 @@ def unpack_tarball( tarball_path, destination  ):
 
     log( 'Unpacking boost tarball ("%s")...' % tarball_path )
 
-    b = os.path.basename( tarball_path )
-    name = b[ 0: b.find( '.' ) ]
-    extension =b[ b.find( '.' ) : ]
+    tarball_name = os.path.basename( tarball_path )
+    extension = tarball_name[ tarball_name.find( '.' ) : ]
 
     if extension in ( ".tar.gz", ".tar.bz2" ):
         mode = os.path.splitext( extension )[1][1:]
-        tar = tarfile.open( tarball_path, 'r|%s' % mode )
+        tar = tarfile.open( tarball_path, 'r:%s' % mode )
         for tarinfo in tar:
             tar.extract( tarinfo, destination )        
             if sys.platform == 'win32' and not tarinfo.isdir():
@@ -181,7 +207,6 @@ def unpack_tarball( tarball_path, destination  ):
         z = zipfile.ZipFile( tarball_path, 'r', zipfile.ZIP_DEFLATED ) 
         for f in z.infolist():
             destination_file_path = os.path.join( destination, f.filename )
-            print f.filename
             if destination_file_path[-1] == "/": # directory 
                 if not os.path.exists( destination_file_path  ):
                     os.makedirs( destination_file_path  )
@@ -191,7 +216,7 @@ def unpack_tarball( tarball_path, destination  ):
                 result.close()
         z.close()
     else:
-        raise "Do not know how to unpack archives with extension \"%s\"" % extension
+        raise 'Do not know how to unpack archives with extension \"%s\"' % extension
 
     boost_dir = find_boost_dirs( destination )[0]
     log( '    Unpacked into directory "%s"' % boost_dir )
@@ -225,11 +250,7 @@ def cvs_checkout( user, tag, args ):
         command = 'checkout boost'
     
     os.chdir( regression_root )
-    retry( 
-         cvs_command
-       , ( user, command )
-       , max_attempts=5
-       )
+    cvs_command( user, command )
 
 
 def cvs_update( user, tag, args ):
@@ -239,11 +260,7 @@ def cvs_update( user, tag, args ):
         command = 'update -dPA'
     
     os.chdir( os.path.join( regression_root, 'boost' ) )
-    retry( 
-         cvs_command
-       , ( user, command )
-       , max_attempts=5
-       )
+    cvs_command( user, command )
 
 
 def format_time( t ):
@@ -252,28 +269,59 @@ def format_time( t ):
         , t
         )
 
+
+def refresh_timestamp():
+    if os.path.exists( timestamp_path ):
+       os. unlink( timestamp_path )
+
+    open( timestamp_path, 'w' ).close()
+
+
 def timestamp():
-    return format_time( 
-          time.gmtime( os.stat( timestamp_path ).st_mtime )
+    return time.strftime(
+          '%Y-%m-%dT%H:%M:%SZ'
+        , time.gmtime( os.stat( timestamp_path ).st_mtime )
         )
 
 
+def get_tarball( tag, proxy, args, **unused ):
+    if args == []: args = [ 'download', 'unpack' ]
+
+    tarball_path = None
+
+    if 'download' in args:
+        tarball_path = download_boost_tarball( regression_root, tag, proxy )
+
+    if 'unpack' in args:
+        if not tarball_path:
+            tarball_path = os.path.join( regression_root, tarball_name_for_tag( tag ) )
+        unpack_tarball( tarball_path, regression_root )
+
+
 def get_source( user, tag, proxy, args, **unused ):
-    open( timestamp_path, 'w' ).close()
+    refresh_timestamp()
     log( 'Getting sources (%s)...' % timestamp() )
 
     if user is not None:
-        cvs_checkout( user, tag, args )
+        retry( 
+              cvs_checkout
+            , ( user, tag, args )
+            )
     else:
-        tarball_path = download_boost_tarball( regression_root, tag, proxy )
-        unpack_tarball( tarball_path, regression_root )
+        retry( 
+              get_tarball
+            , ( tag, proxy, args )
+            )
 
 
 def update_source( user, tag, proxy, args, **unused ):
     if user is not None or os.path.exists( os.path.join( boost_root, 'CVS' ) ):
         open( timestamp_path, 'w' ).close()
         log( 'Updating sources from CVS (%s)...' % timestamp() )
-        cvs_update( user, tag, args )
+        retry( 
+              cvs_update
+            , ( user, tag, args )
+            )
     else:
         get_source( user, tag, proxy, args )
 
@@ -310,6 +358,12 @@ def build_if_needed( tool, toolset, toolsets ):
     if toolset is None:
         if toolsets is not None:
             toolset = string.split( toolsets, ',' )[0]
+            if not tool[ 'is_supported_toolset' ]( toolset ):
+                log( 'Warning: Specified toolset (%s) cannot be used to bootstrap "%s".'\
+                     % ( toolset, tool[ 'name' ] ) )
+
+                toolset = tool[ 'default_toolset' ]
+                log( '         Using default toolset for the platform (%s).' % toolset )
         else:
             toolset = tool[ 'default_toolset' ]
             log( 'Warning: No bootstrap toolset for "%s" was specified.' % tool[ 'name' ] )
@@ -320,7 +374,7 @@ def build_if_needed( tool, toolset, toolsets ):
         build_cmd = tool[ 'build_cmd' ]( toolset )
         log( 'Building "%s" (%s)...' % ( tool[ 'name'], build_cmd ) )
         utils.system( [ 
-              'cd %s' % tool[ 'source_dir' ]
+              'cd "%s"' % tool[ 'source_dir' ]
             , build_cmd
             ] )
     else:
@@ -389,10 +443,18 @@ def setup(
 
 
 def bjam_command( toolsets ):
-    result = '"%s"' % tool_path( bjam )
+    build_path = regression_root
+    if build_path[-1] == '\\': build_path += '\\'
+    result = '"%s" "-sBOOST_BUILD_PATH=%s" "-sBOOST_ROOT=%s"'\
+        % (
+            tool_path( bjam )
+          , build_path
+          , boost_root
+          )
+    
     if not toolsets is None:
         result += ' "-sTOOLS=%s"' % string.join( string.split( toolsets, ',' ), ' ' )
-    result += ' "-sBOOST_ROOT=%s"' % boost_root
+
     return result
 
 
@@ -412,7 +474,7 @@ def start_build_monitor( timeout ):
     if sys.platform == 'win32':
         build_monitor_path = tool_path( 'build_monitor.exe' )
         if os.path.exists( build_monitor_path ):
-            utils.system( [ 'start /belownormal %s bjam.exe %d' % ( build_monitor_path, timeout*60 ) ] )
+            utils.system( [ 'start /belownormal "" "%s" bjam.exe %d' % ( build_monitor_path, timeout*60 ) ] )
         else:
             log( 'Warning: Build monitor is not found at "%s"' % build_monitor_path )
 
@@ -421,14 +483,14 @@ def stop_build_monitor():
     if sys.platform == 'win32':
         build_monitor_path = tool_path( 'build_monitor.exe' )
         if os.path.exists( build_monitor_path ):
-            utils.system( [ '%s build_monitor' %  tool_path( 'pskill.exe' ) ] )
+            utils.system( [ '"%s" build_monitor' %  tool_path( 'pskill.exe' ) ] )
 
 
 def run_process_jam_log():
     log( 'Getting test case results out of "%s"...' % regression_log )
 
     utils.checked_system( [ 
-        '%s %s <%s' % (
+        '"%s" "%s" <"%s"' % (
               tool_path( process_jam_log )
             , regression_results
             , regression_log
@@ -467,7 +529,7 @@ def test(
             rmtree( results_status )
 
         if "test" in args:
-            test_cmd = '%s -d2 --dump-tests %s "-sALL_LOCATE_TARGET=%s" >>%s 2>&1' % (
+            test_cmd = '%s -d2 --dump-tests %s "-sALL_LOCATE_TARGET=%s" >>"%s" 2>&1' % (
                   bjam_command( toolsets )
                 , bjam_options
                 , regression_results
@@ -498,14 +560,15 @@ def collect_logs(
         ):
     import_utils()
     
-    global comment_path
     if comment is None:
+        comment = 'comment.html'
+
+    comment_path = os.path.join( regression_root, comment )
+    if not os.path.exists( comment_path ):
         log( 'Comment file "%s" not found; creating default comment.' % comment_path )
         f = open( comment_path, 'w' )
-        f.write( '<p>Tests are run on %s platform.</p>' % string.capitalize( sys.platform ) )
+        f.write( '<p>Tests are run on %s platform.</p>' % platform_name() )
         f.close()
-    else: 
-        comment_path = os.path.join( regression_root, comment )
     
     run_type = ''
     if incremental: run_type = 'incremental'
@@ -537,25 +600,56 @@ def upload_logs(
           tag
         , runner
         , user
+        , ftp_proxy
+        , debug_level
         , **unused
         ):
     import_utils()
     from runner import upload_logs
-    upload_logs( regression_results, runner, tag, user )
+    retry(
+          upload_logs
+        , ( regression_results, runner, tag, user, ftp_proxy, debug_level )
+        )
 
 
-def update_itself( **unused ):
+def update_itself( tag, **unused ):
     source = os.path.join( xsl_reports_dir, 'runner', os.path.basename( sys.argv[0] ) )
-    log( 'Updating %s from %s...' % ( sys.argv[0], source )  )
+    self = os.path.join( regression_root, os.path.basename( sys.argv[0] ) )
+
+    log( 'Updating %s from %s...' % ( self, source )  )
     log( '    Checking modification dates...' )
-    if os.stat( sys.argv[0] ).st_mtime > os.stat( source ).st_mtime:
+    if os.stat( self ).st_mtime > os.stat( source ).st_mtime:
         log( 'Warning: The current version of script appears to be newer than the source.' )
         log( '         Update skipped.' )
     else:
         log( '    Saving a backup copy of the current script...' )
-        shutil.move( sys.argv[0], '%s~' % sys.argv[0] )
-        log( '    Replacing %s with a newer version...' % sys.argv[0] )
-        shutil.copy2( source, sys.argv[0] )
+        os.chmod( self, stat.S_IWRITE ) # Win32 workaround
+        shutil.move( self, '%s~' % self )
+        log( '    Replacing %s with a newer version...' % self )
+        shutil.copy2( source, self )
+
+
+def send_mail( smtp_login, mail, subject, msg = '', debug_level = 0 ):
+    import smtplib
+    if not smtp_login:
+        server_name = 'mail.%s' % mail.split( '@' )[-1]
+        user_name = None
+        password = None
+    else:
+        server_name = smtp_login.split( '@' )[-1]
+        ( user_name, password ) = string.split( smtp_login.split( '@' )[0], ':' )
+        
+    log( '    Sending mail through "%s"...' % server_name )
+    smtp_server = smtplib.SMTP( server_name )
+    smtp_server.set_debuglevel( debug_level )
+    if user_name:
+        smtp_server.login( user_name, password )
+    
+    smtp_server.sendmail( 
+          mail
+        , [ mail ]
+        , 'Subject: %s\nTo: %s\n\n%s' % ( subject, mail, msg )
+        )
 
 
 def regression( 
@@ -570,19 +664,28 @@ def regression(
         , bjam_toolset
         , pjl_toolset
         , incremental
+        , force_update
         , monitored
         , timeout
         , mail = None
+        , smtp_login = None
         , proxy = None
+        , ftp_proxy = None
+        , debug_level = 0
         , args = []
         ):
 
     try:
-        mail_subject = 'Boost regression for %s on %s ' % ( tag, string.split(socket.gethostname(), '.')[0] )
+        mail_subject = 'Boost regression for %s on %s' % ( tag, string.split(socket.gethostname(), '.')[0] )
         start_time = time.localtime()
         if mail:
             log( 'Sending start notification to "%s"' % mail )
-            utils.send_mail( mail, mail_subject + ' started at %s.' % format_time( start_time ) )
+            send_mail(
+                  smtp_login
+                , mail
+                , '%s started at %s.' % ( mail_subject, format_time( start_time ) )
+                , debug_level = debug_level
+                )
 
         if local is not None:
             log( 'Using local file "%s"' % local )
@@ -591,15 +694,10 @@ def regression(
             tag = b[ 0: b.find( '.' ) ]
             log( 'Tag: "%s"' % tag  )
             
-            if not os.path.isdir( local ):
-                unpack_tarball( local, regression_root )
-            else:
-                if b != 'boost':
-                    log( 'Renaming "%s" into "%s"' % ( local, boost_root ) )
-                    os.rename( local, boost_root )
-                    
+            unpack_tarball( local, regression_root )
         else:
-            if incremental:
+            if incremental or force_update:
+                if not incremental: cleanup( [ 'bin' ] )
                 update_source( user, tag, proxy, [] )
             else:
                 cleanup( [] )
@@ -608,32 +706,36 @@ def regression(
         setup( comment, toolsets, bjam_toolset, pjl_toolset, monitored, proxy, [] )
         test( toolsets, bjam_options, monitored, timeout, [] )
         collect_logs( tag, runner, platform, user, comment, incremental, [] )
-        upload_logs( tag, runner, user )
-        update_itself()
+        upload_logs( tag, runner, user, ftp_proxy, debug_level )
+        update_itself( tag )
         
         if mail:
             log( 'Sending report to "%s"' % mail )
             end_time = time.localtime()
-            utils.send_mail( 
-                  mail
-                , mail_subject + ' completed successfully at %s.' % format_time( end_time )
+            send_mail( 
+                  smtp_login
+                , mail
+                , '%s completed successfully at %s.' % ( mail_subject, format_time( end_time ) )
+                , debug_level = debug_level
                 )
     except:
         if mail:
             log( 'Sending report to "%s"' % mail )
-            msg = regression_log + [ '' ] + apply( traceback.format_exception, sys.exc_info() ) 
+            traceback_ = '\n'.join( apply( traceback.format_exception, sys.exc_info() ) )
             end_time = time.localtime()
-            utils.send_mail( 
-                  mail
-                , mail_subject + ' failed at %s.' % format_time( end_time )
-                , '\n'.join( msg )
+            send_mail(
+                  smtp_login
+                , mail
+                , '%s failed at %s.' % ( mail_subject, format_time( end_time ) )
+                , traceback_
+                , debug_level
                 )
         raise
 
 
 def show_revision( **unused ):
-    modified = '$Date: 2004/11/02 08:49:21 $'
-    revision = '$Revision: 1.32.2.5 $'
+    modified = '$Date: 2005/07/26 11:24:23 $'
+    revision = '$Revision: 1.56 $'
 
     import re
     re_keyword_value = re.compile( r'^\$\w+:\s+(.*)\s+\$$' )
@@ -655,8 +757,12 @@ def accept_args( args ):
         , 'pjl-toolset='
         , 'timeout='
         , 'mail='
+        , 'smtp-login='
         , 'proxy='
+        , 'ftp-proxy='
+        , 'debug-level='
         , 'incremental'
+        , 'force-update'
         , 'monitored'
         , 'help'
         ]
@@ -664,25 +770,25 @@ def accept_args( args ):
     options = {
           '--tag'           : 'CVS-HEAD'
         , '--local'         : None
-        , '--platform'      : sys.platform
+        , '--platform'      : platform_name()
         , '--user'          : None
         , '--comment'       : None
-        , '--bjam-options'  : ''
         , '--toolsets'      : None
+        , '--bjam-options'  : ''
         , '--bjam-toolset'  : None
         , '--pjl-toolset'   : None
         , '--timeout'       : 5
         , '--mail'          : None
+        , '--smtp-login'    : None
         , '--proxy'         : None
+        , '--debug-level'   : 0
+        , '--ftp-proxy'     : None
         }
     
-    defaults_num = len( options )
-
     ( option_pairs, other_args ) = getopt.getopt( args, '', args_spec )
     map( lambda x: options.__setitem__( x[0], x[1] ), option_pairs )
 
-    
-    if  options.has_key( '--help' ):
+    if not options.has_key( '--runner' ) or options.has_key( '--help' ):
         usage()
         sys.exit( 1 )
 
@@ -698,10 +804,14 @@ def accept_args( args ):
         , 'bjam_toolset'    : options[ '--bjam-toolset' ]
         , 'pjl_toolset'     : options[ '--pjl-toolset' ]
         , 'incremental'     : options.has_key( '--incremental' )
+        , 'force_update'    : options.has_key( '--force-update' )
         , 'monitored'       : options.has_key( '--monitored' )
         , 'timeout'         : options[ '--timeout' ]
         , 'mail'            : options[ '--mail' ]
+        , 'smtp_login'      : options[ '--smtp-login' ]
         , 'proxy'           : options[ '--proxy' ]
+        , 'ftp_proxy'       : options[ '--ftp-proxy' ]
+        , 'debug_level'     : int(options[ '--debug-level' ])
         , 'args'            : other_args
         }
 
@@ -733,6 +843,8 @@ Options:
 \t--comment       an HTML comment file to be inserted in the reports
 \t                ('comment.html' by default)
 \t--incremental   do incremental run (do not remove previous binaries)
+\t--force-update  do a CVS update (if applicable) instead of a clean
+\t                checkout, even when performing a full run
 \t--monitored     do a monitored run
 \t--timeout       specifies the timeout, in minutes, for a single test
 \t                run/compilation (enforced only in monitored runs, 5 by 
@@ -744,21 +856,27 @@ Options:
 \t--pjl-toolset   bootstrap toolset for 'process_jam_log' executable
 \t                (optional)
 \t--mail          email address to send run notification to (optional)
+\t--smtp-login    STMP server address/login information, in the following
+\t                form: <user>:<password>@<host>[:<port>] (optional).
 \t--proxy         HTTP proxy server address and port (e.g. 
 \t                'http://www.someproxy.com:3128', optional)
+\t--ftp-proxy     FTP proxy server (e.g. 'ftpproxy', optional)
+\t--debug-level   debugging level; controls the amount of debugging 
+\t                output printed; 0 by default (no debug output)
 ''' % '\n\t'.join( commands.keys() )
 
     print 'Example:\n\t%s --runner=Metacomm\n' % os.path.basename( sys.argv[0] )
     print 'For more documentation, see http://tinyurl.com/4f2zp\n'
 
 
-if len(sys.argv) > 1 and sys.argv[1] in commands:
-    command = sys.argv[1]
-    args = sys.argv[ 2: ]
-    if command not in [ 'collect-logs', 'upload-logs' ]:
-        args.insert( 0, '--runner=' )
-else:
-    command = 'regression'
-    args = sys.argv[ 1: ]
-    
-commands[ command ]( **accept_args( args ) )
+if __name__ == '__main__':
+    if len(sys.argv) > 1 and sys.argv[1] in commands:
+        command = sys.argv[1]
+        args = sys.argv[ 2: ]
+        if command not in [ 'collect-logs', 'upload-logs' ]:
+            args.insert( 0, '--runner=' )
+    else:
+        command = 'regression'
+        args = sys.argv[ 1: ]
+
+    commands[ command ]( **accept_args( args ) )
